@@ -1,7 +1,4 @@
 package Net::CLI::Interact::Action;
-{
-  $Net::CLI::Interact::Action::VERSION = '2.143070';
-}
 
 use Moo;
 use Sub::Quote;
@@ -91,20 +88,12 @@ sub num_params {
 
 1;
 
-# ABSTRACT: Sent data or matched response from connected device
-
-
-__END__
 =pod
 
 =head1 NAME
 
 Net::CLI::Interact::Action - Sent data or matched response from connected device
 
-=head1 VERSION
-
-version 2.143070
-
 =head1 DESCRIPTION
 
 This class is used internally by L<Net::CLI::Interact> and it's unlikely that
@@ -186,16 +175,4 @@ C<response> without affecting the original Action. Used when preparing to
 execute an Action which has been retrieved from the
 L<Phrasebook|Net::CLI::Interact::Phrasebook>.
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
