@@ -1,7 +1,4 @@
 package Net::CLI::Interact::ActionSet;
-{
-  $Net::CLI::Interact::ActionSet::VERSION = '2.143070';
-}
 
 use Moo;
 use Sub::Quote;
@@ -165,20 +162,12 @@ sub _marshall_responses {
 
 1;
 
-# ABSTRACT: Conversation of Send and Match Actions
-
-
-__END__
 =pod
 
 =head1 NAME
 
 Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
 
-=head1 VERSION
-
-version 2.143070
-
 =head1 DESCRIPTION
 
 This class is used internally by L<Net::CLI::Interact> and it's unlikely that
@@ -287,16 +276,5 @@ L<Net::CLI::Interact::Role::Iterator>
 
 =back
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
