@@ -1,7 +1,4 @@
 package Net::CLI::Interact::Role::Engine;
-{
-  $Net::CLI::Interact::Role::Engine::VERSION = '2.143070';
-}
 
 {
     package # hide from pause
@@ -48,7 +45,7 @@ use Net::CLI::Interact::ActionSet;
 use Class::Load ();
 
 # try to load Data::Printer for last_actionset debug output
-if (Class::Load::try_load_class('Data::Printer')) {
+if (Class::Load::try_load_class('Data::Printer', {-version => '0.27'})) {
     Data::Printer->import({class => { expand => 'all' }});
 }
 
@@ -62,8 +59,9 @@ sub _trigger_last_actionset {
     my ($self, $new) = @_;
     $self->logger->log('prompt', 'notice',
         sprintf ('output matching prompt was "%s"', $new->item_at(-1)->response));
-    if (Class::Load::is_class_loaded('Data::Printer')) {
-        $self->logger->log('object', 'debug', Data::Printer::p($new));
+    if (Class::Load::is_class_loaded('Data::Printer', {-version => '0.27'})) {
+        Data::Printer::p($new, output => \my $debug);
+        $self->logger->log('object', 'debug', $debug);
     }
 }
 
@@ -180,20 +178,12 @@ sub _execute_actions {
 
 1;
 
-# ABSTRACT: Statement execution engine
-
-
-__END__
 =pod
 
 =head1 NAME
 
 Net::CLI::Interact::Role::Engine - Statement execution engine
 
-=head1 VERSION
-
-version 2.143070
-
 =head1 DESCRIPTION
 
 This module is the core of L<Net::CLI::Interact>, and serves to take entries
@@ -306,16 +296,5 @@ L<Net::CLI::Interact::Role::Prompt>
 
 =back
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
