@@ -1,7 +1,4 @@
 package Net::CLI::Interact::Role::Iterator;
-{
-  $Net::CLI::Interact::Role::Iterator::VERSION = '2.143070';
-}
 
 use Moo::Role;
 use Sub::Quote;
@@ -81,20 +78,12 @@ sub reset { (shift)->_position(-1) }
 
 1;
 
-# ABSTRACT: Array-based Iterator
-
-
-__END__
 =pod
 
 =head1 NAME
 
 Net::CLI::Interact::Role::Iterator - Array-based Iterator
 
-=head1 VERSION
-
-version 2.143070
-
 =head1 SYNOPSIS
 
  my $count = $iter->count;
@@ -182,16 +171,5 @@ cursor. It returns C<undef> if you are already at the end of the sequence.
 
 Resets the cursor so you can iterate through the sequence of elements again.
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
