@@ -1,7 +1,4 @@
 package Net::CLI::Interact::Transport::Loopback;
-{
-  $Net::CLI::Interact::Transport::Loopback::VERSION = '2.143070';
-}
 
 use Moo;
 use Sub::Quote;
@@ -45,10 +42,6 @@ sub runtime_options {
 
 1;
 
-# ABSTRACT: Testable CLI connection
-
-
-__END__
 =pod
 
 =head1 NAME
@@ -98,16 +91,5 @@ L<Net::CLI::Interact::Transport::Base>
 
 =back
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
