@@ -1,7 +1,4 @@
 package Net::CLI::Interact::Transport::Telnet;
-{
-  $Net::CLI::Interact::Transport::Telnet::VERSION = '2.143070';
-}
 
 use Moo;
 use Sub::Quote;
@@ -87,20 +84,12 @@ sub runtime_options {
 
 1;
 
-# ABSTRACT: TELNET based CLI connection
-
-
-__END__
 =pod
 
 =head1 NAME
 
 Net::CLI::Interact::Transport::Telnet - TELNET based CLI connection
 
-=head1 VERSION
-
-version 2.143070
-
 =head1 DESCRIPTION
 
 This module provides a wrapped instance of a TELNET client for use by
@@ -164,16 +153,5 @@ L<Net::CLI::Interact::Transport::Base>
 
 =back
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
